@@ -1,9 +1,9 @@
 import sys
-from .listreqs_sh import listreqs_shell
+from .listreqs_sh import listreqs
 
 
 def main():
-    listreqs_shell()
+    listreqs()
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
